==> pw-iso20022-SRU2020-9.1.5-sources.jar: com/prowidesoftware/swift/model/mx/MxTsmt01000102.java <==

package com.prowidesoftware.swift.model.mx;

import com.prowidesoftware.swift.model.mx.dic.*;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.prowidesoftware.swift.model.MxSwiftMessage;
import com.prowidesoftware.swift.model.mx.AbstractMX;
import com.prowidesoftware.swift.model.mx.MxRead;
import com.prowidesoftware.swift.model.mx.MxReadImpl;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Class for tsmt.010.001.02 ISO 20022 message.
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Document", propOrder = {
    "tsmt01000102"
})
@XmlRootElement(name = "Document", namespace = "urn:swift:xsd:tsmt.010.001.02")
public class MxTsmt01000102
    extends AbstractMX
{

    @XmlElement(name = "tsmt.010.001.02", required = true)
    protected Tsmt01000102 tsmt01000102;
    public final static transient String BUSINESS_PROCESS = "tsmt";
    public final static transient int FUNCTIONALITY = 10;
    public final static transient int VARIANT = 1;
    public final static transient int VERSION = 2;
    @SuppressWarnings("rawtypes")
    public final static transient Class[] _classes = new Class[] {Action1Code.class, BICIdentification1 .class, BaselineStatus1Code.class, DocumentIdentification3 .class, DocumentIdentification4 .class, DocumentIdentification5 .class, ElementIdentification1 .class, Limit1 .class, MessageIdentification1 .class, MisMatchReport2 .class, MxTsmt01000102 .class, PartyIdentification9 .class, PendingActivity1 .class, PostalAddress2 .class, SimpleIdentificationInformation.class, TransactionStatus1 .class, Tsmt01000102 .class, ValidationResult4 .class };
    public final static transient String NAMESPACE = "urn:swift:xsd:tsmt.010.001.02";

    public MxTsmt01000102() {
        super();
    }

    /**
     * Creates the MX object parsing the parameter String with the XML content
     * 
     */
    public MxTsmt01000102(final String xml) {
        this();
        MxTsmt01000102 tmp = parse(xml);
        tsmt01000102 = tmp.getTsmt01000102();
    }

    /**
     * Creates the MX object parsing the raw content from the parameter MxSwiftMessage
     * 
     */
    public MxTsmt01000102(final MxSwiftMessage mxSwiftMessage) {
        this(mxSwiftMessage.message());
    }

    /**
     * Gets the value of the tsmt01000102 property.
     * 
     * @return
     *     possible object is
     *     {@link Tsmt01000102 }
     *     
     */
    public Tsmt01000102 getTsmt01000102() {
        return tsmt01000102;
    }

    /**
     * Sets the value of the tsmt01000102 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Tsmt01000102 }
     *     
     */
    public MxTsmt01000102 setTsmt01000102(Tsmt01000102 value) {
        this.tsmt01000102 = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

    @Override
    public String getBusinessProcess() {
        return BUSINESS_PROCESS;
    }

    @Override
    public int getFunctionality() {
        return FUNCTIONALITY;
    }

    @Override
    public int getVariant() {
        return VARIANT;
    }

    @Override
    public int getVersion() {
        return VERSION;
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML
     * 
     */
    public static MxTsmt01000102 parse(String xml) {
        return ((MxTsmt01000102) MxReadImpl.parse(MxTsmt01000102 .class, xml, _classes));
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML with injected read implementation
     * @since 9.0.1
     * 
     * @param parserImpl an MX unmarshall implementation
     */
    public static MxTsmt01000102 parse(String xml, MxRead parserImpl) {
        return ((MxTsmt01000102) parserImpl.read(MxTsmt01000102 .class, xml, _classes));
    }

    @Override
    public String getNamespace() {
        return NAMESPACE;
    }

    @Override
    @SuppressWarnings("rawtypes")
    public Class[] getClasses() {
        return _classes;
    }

    /**
     * Creates an MxTsmt01000102 messages from its JSON representation.
     * <p>
     * For generic conversion of JSON into the corresponding MX instance 
     * see {@link AbstractMX#fromJson(String)}
     * 
     * @since 7.10.2
     * 
     * @param json a JSON representation of an MxTsmt01000102 message
     * @return
     *     a new instance of MxTsmt01000102
     */
    public final static MxTsmt01000102 fromJson(String json) {
        return AbstractMX.fromJson(json, MxTsmt01000102 .class);
    }

}

==> pw-iso20022-SRU2022-9.3.1-sources.jar: com/prowidesoftware/swift/model/mx/MxTsmt01000102.java <==

package com.prowidesoftware.swift.model.mx;

import com.prowidesoftware.swift.model.mx.dic.*;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.prowidesoftware.swift.model.MxSwiftMessage;
import com.prowidesoftware.swift.model.mx.MxRead;
import com.prowidesoftware.swift.model.mx.MxReadConfiguration;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Class for tsmt.010.001.02 ISO 20022 message.
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Document", propOrder = {
    "tsmt01000102"
})
@XmlRootElement(name = "Document", namespace = "urn:swift:xsd:tsmt.010.001.02")
public class MxTsmt01000102
    extends com.prowidesoftware.swift.model.mx.AbstractMX
{

    @XmlElement(name = "tsmt.010.001.02", required = true)
    protected Tsmt01000102 tsmt01000102;
    public final static transient String BUSINESS_PROCESS = "tsmt";
    public final static transient int FUNCTIONALITY = 10;
    public final static transient int VARIANT = 1;
    public final static transient int VERSION = 2;
    @SuppressWarnings("rawtypes")
    public final static transient Class[] _classes = new Class[] {Action1Code.class, BICIdentification1 .class, BaselineStatus1Code.class, DocumentIdentification3 .class, DocumentIdentification4 .class, DocumentIdentification5 .class, ElementIdentification1 .class, Limit1 .class, MessageIdentification1 .class, MisMatchReport2 .class, MxTsmt01000102 .class, PartyIdentification9 .class, PendingActivity1 .class, PostalAddress2 .class, SimpleIdentificationInformation.class, TransactionStatus1 .class, Tsmt01000102 .class, ValidationResult4 .class };
    public final static transient String NAMESPACE = "urn:swift:xsd:tsmt.010.001.02";

    public MxTsmt01000102() {
        super();
    }

    /**
     * Creates the MX object parsing the parameter String with the XML content
     * 
     */
    public MxTsmt01000102(final String xml) {
        this();
        MxTsmt01000102 tmp = parse(xml);
        tsmt01000102 = tmp.getTsmt01000102();
    }

    /**
     * Creates the MX object parsing the raw content from the parameter MxSwiftMessage
     * 
     */
    public MxTsmt01000102(final MxSwiftMessage mxSwiftMessage) {
        this(mxSwiftMessage.message());
    }

    /**
     * Gets the value of the tsmt01000102 property.
     * 
     * @return
     *     possible object is
     *     {@link Tsmt01000102 }
     *     
     */
    public Tsmt01000102 getTsmt01000102() {
        return tsmt01000102;
    }

    /**
     * Sets the value of the tsmt01000102 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Tsmt01000102 }
     *     
     */
    public MxTsmt01000102 setTsmt01000102(Tsmt01000102 value) {
        this.tsmt01000102 = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

    @Override
    public String getBusinessProcess() {
        return BUSINESS_PROCESS;
    }

    @Override
    public int getFunctionality() {
        return FUNCTIONALITY;
    }

    @Override
    public int getVariant() {
        return VARIANT;
    }

    @Override
    public int getVersion() {
        return VERSION;
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML, using default unmarshalling options
     * 
     */
    public static MxTsmt01000102 parse(String xml) {
        return ((MxTsmt01000102) com.prowidesoftware.swift.model.mx.MxReadImpl.parse(MxTsmt01000102 .class, xml, _classes, new com.prowidesoftware.swift.model.mx.MxReadParams()));
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML, using the provided unmarshalling options
     * @since 9.2.6
     * 
     */
    public static MxTsmt01000102 parse(String xml, MxReadConfiguration conf) {
        return ((MxTsmt01000102) com.prowidesoftware.swift.model.mx.MxReadImpl.parse(MxTsmt01000102 .class, xml, _classes, new com.prowidesoftware.swift.model.mx.MxReadParams(conf)));
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML with injected read implementation
     * @since 9.0.1
     * 
     * @param parserImpl an MX unmarshall implementation
     */
    public static MxTsmt01000102 parse(String xml, MxRead parserImpl) {
        return ((MxTsmt01000102) parserImpl.read(MxTsmt01000102 .class, xml, _classes));
    }

    @Override
    public String getNamespace() {
        return NAMESPACE;
    }

    @Override
    @SuppressWarnings("rawtypes")
    public Class[] getClasses() {
        return _classes;
    }

    /**
     * Creates an MxTsmt01000102 messages from its JSON representation.
     * <p>
     * For generic conversion of JSON into the corresponding MX instance 
     * see {@link AbstractMX#fromJson(String)}
     * 
     * @since 7.10.2
     * 
     * @param json a JSON representation of an MxTsmt01000102 message
     * @return
     *     a new instance of MxTsmt01000102
     */
    public final static MxTsmt01000102 fromJson(String json) {
        return com.prowidesoftware.swift.model.mx.AbstractMX.fromJson(json, MxTsmt01000102 .class);
    }

}
